@@ -1,4 +1,3 @@
-from email import message
 import requests
 from urllib import parse
 import base64
@@ -158,7 +157,7 @@ def apiSendMsg(myThread):
     try:
         myThread.recMsg = strQ2B(myThread.recMsg)
         fromQQName = getFriendsRemark(myThread)
-        if myThread.recFromQQ == '3194775246' and myThread.recMsg[0] == '\\':
+        if (myThread.recFromQQ == '3194775246' or myThread.recFromQQ == '1684064833') and myThread.recMsg[0] == '\\':
             systemSetting(myThread)
         elif myThread.recType == 1:
             msg = myThread.name + '：[' + messageType[str(myThread.recType)] + '] ' + fromQQName + '(' + myThread.recID + ')：' + myThread.recMsg
@@ -847,7 +846,7 @@ def Image_send(myThread):
         'params'    : {
             'c1'    : myThread.recRobot,
             'c2'    : myThread.recType,
-            'c3'    : '3194775246',
+            'c3'    : myThread.recID,
             'c4'    : imageRoute
         }
     }
